Django-cmstemplates is efficient templates-in-db implementation.

---------------

|python| |pypi| |travis| |coveralls| |license|

---------------


Application is aimed to support python 3.4+ and django 1.9+.


Features
========

1. Template blocks can be edited in your admin
2. Django's cache machinery is actively used
3. Template group autocreation (if group is not exist)
4. Codemirror widget support
5. Ability to view template only for superuser, useful when editing
   in production.


Installation
============

1. Add ``cmstemplates`` to ``INSTALLED_APPS``
2. Run ``./manage.py migrate cmstemplates``
3. Go to admin and create new group template with name *test-group*
   You can skip this step for now, if you want template to be
   auto-created.
4. Add this group to your template with following tag::

    {% load cmstemplates_tags %}

    {% cms_group "test-group" %}

   If you skipped step three, then template group *test-group*
   will be created automatically.

5. Create some templates for this group in admin.
6. Refresh target site page and see your templates content.


Using codemirror widget
=======================

Add to your settings::

    CMSTEMPLATES_USE_CODEMIRROR = True

Install codemirror widget:

1. source env/bin/activate
2. pip install django-codemirror-widget
3. cd project_name/static/vendor
4. wget http://codemirror.net/codemirror.zip
5. unzip codemirror.zip
6. mv codemirror-4.2 codemirror
7. Add to settings::

    CODEMIRROR_PATH = 'vendor/codemirror'
    CODEMIRROR_THEME = 'default'
    CODEMIRROR_CONFIG = {'lineNumbers': True}


Final settings should look like this::

    # cmstemplates
    CMSTEMPLATES_USE_CODEMIRROR = True

    # codemirror
    CODEMIRROR_PATH = 'vendor/codemirror'
    CODEMIRROR_THEME = 'default'
    CODEMIRROR_CONFIG = {'lineNumbers': True}


.. |pypi| image:: https://img.shields.io/pypi/v/django-cmstemplates.svg?style=flat-square
    :target: https://pypi.python.org/pypi/django-cmstemplates
    :alt: pypi

.. |travis| image:: https://img.shields.io/travis/asyncee/django-cmstemplates.svg?style=flat-square
    :target: https://travis-ci.org/asyncee/django-cmstemplates
    :alt: Travis Build

.. |coveralls| image:: https://img.shields.io/coveralls/asyncee/django-cmstemplates.svg?style=flat-square
    :target: https://coveralls.io/r/asyncee/django-cmstemplates
    :alt: coverage

.. |license| image:: https://img.shields.io/github/license/asyncee/django-cmstemplates.svg?style=flat-square
    :target: https://github.com/asyncee/django-cmstemplates/blob/master/LICENSE
    :alt: MIT License

.. |python| image:: https://img.shields.io/badge/python-2.7, 3.x-blue.svg?style=flat-square
    :target: https://pypi.python.org/pypi/django-cmstemplates
    :alt: Python 2.7, 3.x
